import TextAideInput from "@/pages/launchSystemV3/components/TextAideInput"
import { txtLength } from "@/utils/utils"
import { Button, Card, Form, Modal, Space, message } from "antd"
import React, { useEffect } from "react"


interface Props {
    textData: any
    value?: any,
    visible?: boolean
    onClose?: () => void
    onChange?: (value: any) => void
}

/**
 * 创意文案
 * @param param0 
 * @returns 
 */
const NewText: React.FC<Props> = ({ visible, onClose, onChange, value, textData }) => {

    /*************************************/
    const [form] = Form.useForm();
    /*************************************/

    const handleOk = (values: any) => {
        console.log(values)
        onChange?.({
            type: 0,
            dynamicCreativesTextDetailDTOList: [values]
        })
    }

    useEffect(() => {
        if (value?.dynamicCreativesTextDetailDTOList) {
            console.log('value?.dynamicCreativesTextDTOS?.dynamicCreativesTextDetailDTOList[0]', value?.dynamicCreativesTextDetailDTOList[0])
            form.setFieldsValue(value?.dynamicCreativesTextDetailDTOList[0])
        }
    }, [value])

    return <Modal
        title={<strong style={{ fontSize: 20 }}>创意文案</strong>}
        visible={visible}
        onCancel={onClose}
        footer={null}
        width={700}
        className={`modalResetCss`}
        bodyStyle={{ padding: '0 0 40px', position: 'relative', borderRadius: '0 0 8px 8px' }}
        maskClosable={false}
    >
        <Form
            form={form}
            name="newText"
            labelAlign='left'
            labelCol={{ span: 5 }}
            colon={false}
            style={{ backgroundColor: '#f1f4fc', maxHeight: 650, overflow: 'hidden', overflowY: 'auto', padding: '0 10px 10px', borderRadius: '0 0 8px 8px' }}
            scrollToFirstError={{
                behavior: 'smooth',
                block: 'center'
            }}
            onFinishFailed={({ errorFields }) => {
                message.error(errorFields?.[0]?.errors?.[0])
            }}
            onFinish={handleOk}
        >
            <Card className="cardResetCss" style={{ marginTop: 10 }}>
                {Object.keys(textData).map(key => {
                    let item = textData[key]
                    let content = item.children.content

                    return <Form.Item
                        label={<strong>{content.description}</strong>}
                        name={item.name}
                        key={key}
                        rules={[{
                            required: item.required, message: '请输入正确的' + content.description, validator: (rule, value) => {
                                if (!value) {
                                    return Promise.reject()
                                } else if (!value.match(RegExp(content.restriction.textRestriction.textPattern))) {
                                    return Promise.reject()
                                } else if (txtLength(value) > content.restriction.textRestriction.maxLength) {
                                    return Promise.reject()
                                }
                                return Promise.resolve()
                            }
                        }]}
                    >
                        <TextAideInput placeholder={'请输入' + content.description} style={{ width: 450 }} maxTextLength={content.restriction.textRestriction.maxLength} />
                    </Form.Item>
                })}
            </Card>
            <Form.Item className="submit_pull">
                <Space>
                    <Button onClick={onClose}>取消</Button>
                    <Button type="primary" htmlType="submit" className="modalResetCss">
                        确定
                    </Button>
                </Space>
            </Form.Item>
        </Form>
    </Modal>
}

export default React.memo(NewText)