import { request } from 'umi';
import { api } from '../api'


/** 新增计划 */
export interface adsPlan {
    channelAdqAccount: any,
    channelMpAccount: any,
    taskName: string,  // 任务名称
    channelMpGoods: any,
    planDto: {
        content: string,    // 外层文案
        planName: string,   // 计划名称
        posType: string,    // 创意样式 311 1707
        putLocation: string,// 流量位 朋友圈 公众平台
        putTarget: string,  // 推广目标 公众号 视频号
        pageId: number,     // 落地页ID
        campaign: string,   // 计划内容
        adgroup: string,    // 广告组内容
        adcreative: string, // 创意内容
        material: string,   // 素材内容
    }
}
export async function addPlanApi(params: adsPlan) {
    return request(api + `/ads/adsNewPlan/addAndCreate`, {
        method: 'POST',
        data: params
    })
}

/** 获取任务列表 */
export interface adsPlanList {
    createStatus?: number[],
    createStartTime?: string,
    createEndTime?: string,
    taskName?: string,
    pageNum: number,
    pageSize: number,
}
export async function getAdsPlanApi(params: adsPlanList) {
    return request(api + `/ads/adsNewPlanTask/list`, {
        method: 'POST',
        data: params
    })
}

/** 删除 */
export async function delBatchAjax(parmas: { taskIds: string }) {
    return request(`${api}/ads/adsNewPlanTask/delBatch/${parmas.taskIds}`, {
        method: 'DELETE'
    })
}
export async function delLogBatchAjax(parmas: { logIds: string }) {
    return request(`${api}/ads/adsNewPlanCreateLog/logDelBatch/${parmas.logIds}`, {
        method: 'DELETE'
    })
}


/** 获取计划列表 */
export interface adsPlanLogList {
    pageNum: number,
    pageSize: number,
    posType: number,
    planId?: number,
    channelId?: number,
    accountIds?: string | string[], // 公众号
    createStatus?: number
    planName?: string, // 计划名称
    taskName?: string, // 任务名称
    createStartTime?: string, // 开始时间
    createEndTime?: string
}
export async function getAdsPlanLogApi(params: adsPlanLogList) {
    return request(api + `/ads/adsNewPlanCreateLog/logList`, {
        method: 'GET',
        params: params
    })
}

/** 批量复制计划接口 */
export interface CopyPlan {
    taskName: string,
    planCreateLogId: number,   // 计划ID
    begin_time: number,        // 开始时间
    end_time: number,          // 结束时间
    copy_count: number,        // 复制数量
    planDtos: {
        posType: number,
        imageUrl?: string, // 广告位图片
        headDescType?: number, // 信息栏类型
        description?: string, // 信息栏文案
        title?: string, // 图文标题
        cardInfoDesc?: string[], // 广告文案
        content?: string,       // 外层文案
        planName: string,      // 计划名称
        putLocation: string,   // 投放渠道
        putTarget: string,     // 投放位置
        pageId: number,        // 落地页ID
        firstContext: string,  // 第一步
        secondContext: string,  // 第二步
        shortVideo?: string,  // 视频信息
    }[]
}
export async function setCopyPlanApi(props: CopyPlan) {
    return request(api + `/ads/adsNewPlan/copyPlan`, {
        method: 'POST',
        data: props
    })
}